# constants.py
"""Constants."""

__all__ = ['mc2',
           'speed_light',
           'alfven_current',
           'mass_rest_electron',
           'clight',
           'MeV']

electron_charge = -1
mc2 = mass_rest_electron = 0.5109989461
speed_light = clight = 299_792_458
alfven_current = 17_000
MeV = 1e6
